@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0109';
+our $VERSION = '0.0110';
 
 use strict;
 use warnings;
@@ -100,7 +100,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0109
+version 0.0110
 
 =head1 SYNOPSIS
 
@@ -133,8 +133,7 @@ of an C<E A D G B E> tuned guitar.
 
 Computed attribute available after construction.
 
-The chord names are given to the module methods as the B<chord_name>.
-They are as follows:
+The known chord names are as follows:
 
   '' (major)
   aug
